@@ -1,7 +1,7 @@
 """ Loop. """
 import time
 
-def data_loop(idle_wait=15, drive_wait=5, charge_wait=5):
+def data_loop(idle_wait=15, drive_wait=5, charge_wait=5, output=print):
     last_km = None
     from .fhs_enyaq_data import get_instruments_with_timeout
     from .config import get_config
@@ -9,7 +9,7 @@ def data_loop(idle_wait=15, drive_wait=5, charge_wait=5):
     config = get_config()
     while True:
         # run
-        print('get instruments.')
+        output('get instruments.')
         instruments = get_instruments_with_timeout(config)
         if instruments is not None:
             send_abrp(config, instruments)
@@ -18,14 +18,14 @@ def data_loop(idle_wait=15, drive_wait=5, charge_wait=5):
                 last_km = instruments['Electric range']
             if instruments['Charging'] == 1:
                 sleep_time = charge_wait * 60
-                print('charging.')
+                output('charging.')
             elif last_km != instruments['Electric range']:
                 sleep_time = drive_wait * 60
-                print('driving.')
+                output('driving.')
             last_km = instruments['Electric range']
             time.sleep(sleep_time)
         else:
-            print('no instruments returned.')
+            output('no instruments returned.')
             time.sleep(120)
 
 
